@@ -1,5 +1,5 @@
 #!/bin/bash
-# To check if "btrfs check" can detect metadata dump (restored by btrfs-iamge)
+# To check if "btrfs check" can detect metadata dump (restored by btrfs-image)
 # and ignore --check-data-csum option
 
 source "$TEST_TOP/common"
@@ -16,10 +16,12 @@ run_check_mount_test_dev
 run_check $SUDO_HELPER dd if=/dev/urandom of="$TEST_MNT/file" bs=4k count=16
 run_check_umount_test_dev
 
+touch restored_image
+chmod a+w restored_image
 run_check $SUDO_HELPER "$TOP/btrfs-image" "$TEST_DEV" "restored_image"
 
 # use prepare_test_dev() to wipe all existing data on $TEST_DEV
-# so there is no way that restored image could have mathcing data csum
+# so there is no way that restored image could have matching data csum
 prepare_test_dev
 
 run_check $SUDO_HELPER "$TOP/btrfs-image" -r "restored_image" "$TEST_DEV"
@@ -27,4 +29,4 @@ run_check $SUDO_HELPER "$TOP/btrfs-image" -r "restored_image" "$TEST_DEV"
 # Should not report any error
 run_check "$TOP/btrfs" check --check-data-csum "$TEST_DEV"
 
-rm -rf -- "restored_image*"
+rm -rf -- "restored_image"
